<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="lt">
<context>
    <name>AirplaneModeItem</name>
    <message>
        <source>Airplane mode enabled</source>
        <translation>Lėktuvo veiksena įjungta</translation>
    </message>
    <message>
        <source>Airplane mode disabled</source>
        <translation>Lėktuvo veiksena išjungta</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Įjungti</translation>
    </message>
    <message>
        <source>Airplane Mode</source>
        <translation>Lėktuvo veiksena</translation>
    </message>
    <message>
        <source>Airplane mode settings</source>
        <translation>Lėktuvo veiksenos nustatymai</translation>
    </message>
</context>
<context>
    <name>AirplaneModePlugin</name>
    <message>
        <source>Airplane Mode</source>
        <translation>Lėktuvo veiksena</translation>
    </message>
</context>
<context>
    <name>BluetoothAdapterItem</name>
    <message>
        <source>My Devices</source>
        <translation>Mano įrenginiai</translation>
    </message>
</context>
<context>
    <name>BluetoothApplet</name>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth nustatymai</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Išjungta</translation>
    </message>
    <message>
        <source>Disable [Airplane Mode](#) first if you want to connect to a Bluetooth</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>BluetoothItem</name>
    <message>
        <source>Turn off</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <source>Turn on</source>
        <translation>Įjungti</translation>
    </message>
    <message>
        <source>Bluetooth settings</source>
        <translation>Bluetooth nustatymai</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 prisijungęs</translation>
    </message>
    <message>
        <source>Connecting...</source>
        <translation>Jungiamasi...</translation>
    </message>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
    <message>
        <source>Turned off</source>
        <translation>Išjungta</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Prisijungęs %1</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Neprisijungęs</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Išjungta</translation>
    </message>
</context>
<context>
    <name>BluetoothPlugin</name>
    <message>
        <source>Bluetooth</source>
        <translation>Bluetooth</translation>
    </message>
</context>
<context>
    <name>BrightnessApplet</name>
    <message>
        <source>Brightness</source>
        <translation>Ryškumas</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Ekrano nustatymai</translation>
    </message>
</context>
<context>
    <name>BrightnessItem</name>
    <message>
        <source>Display settings</source>
        <translation>Ekrano nustatymai</translation>
    </message>
</context>
<context>
    <name>BrightnessPlugin</name>
    <message>
        <source>Brightness</source>
        <translation>Ryškumas</translation>
    </message>
</context>
<context>
    <name>CWeekWidget</name>
    <message>
        <source>Sun</source>
        <translation>Sek</translation>
    </message>
    <message>
        <source>Mon</source>
        <translation>Pir</translation>
    </message>
    <message>
        <source>Tue</source>
        <translation>Ant</translation>
    </message>
    <message>
        <source>Wed</source>
        <translation>Tre</translation>
    </message>
    <message>
        <source>Thu</source>
        <translation>Ket</translation>
    </message>
    <message>
        <source>Fri</source>
        <translation>Pen</translation>
    </message>
    <message>
        <source>Sat</source>
        <translation>Šeš</translation>
    </message>
</context>
<context>
    <name>DBusAdaptors</name>
    <message>
        <source>Add keyboard layout</source>
        <translation>Pridėti klaviatūros išdėstymą</translation>
    </message>
</context>
<context>
    <name>DatetimePlugin</name>
    <message>
        <source>Datetime</source>
        <translation>Data ir laikas</translation>
    </message>
    <message>
        <source>12-hour time</source>
        <translation>12 valandų laikas</translation>
    </message>
    <message>
        <source>24-hour time</source>
        <translation>24 valandų laikas</translation>
    </message>
    <message>
        <source>Time settings</source>
        <translation>Laiko nustatymai</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Atverti kalendorių</translation>
    </message>
</context>
<context>
    <name>DatetimeWidget</name>
    <message>
        <source>Monday</source>
        <translation>Pirmadienis</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Antradienis</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Trečiadienis</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Ketvirtadienis</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Penktadienis</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Šeštadienis</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sekmadienis</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>pirmadienis</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>antradienis</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>trečiadienis</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>ketvirtadienis</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>penktadienis</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>šeštadienis</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>sekmadienis</translation>
    </message>
</context>
<context>
    <name>DeviceControlWidget</name>
    <message>
        <source>Other Devices</source>
        <translation>Kiti įrenginiai</translation>
    </message>
</context>
<context>
    <name>DndModeItem</name>
    <message>
        <source>DND Mode</source>
        <translation>DND režimas</translation>
    </message>
    <message>
        <source>DND mode settings</source>
        <translation>Naudotojo režimo nustatymai</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Įjungti</translation>
    </message>
    <message>
        <source>DND mode enabled</source>
        <translation>DND režimas įjungtas</translation>
    </message>
    <message>
        <source>DND mode disabled</source>
        <translation>DND režimas išjungtas</translation>
    </message>
</context>
<context>
    <name>DndModePlugin</name>
    <message>
        <source>DND Mode</source>
        <translation>DND režimas</translation>
    </message>
</context>
<context>
    <name>EyeComfortModeItem</name>
    <message>
        <source>Eye Comfort</source>
        <translation>Vidinės tarmybė</translation>
    </message>
    <message>
        <source>Eye comfort enabled</source>
        <translation>Vidinė tarmybė įjungta</translation>
    </message>
    <message>
        <source>Eye comfort disabled</source>
        <translation>Vidinė tarmybė išjungta</translation>
    </message>
    <message>
        <source>Display settings</source>
        <translation>Vidutinio nustatymai</translation>
    </message>
    <message>
        <source>Eye comfort</source>
        <translation>Vidinė tarmybė</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Apipavidalinimas</translation>
    </message>
    <message>
        <source>On</source>
        <translation> Įjungta</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Išjungta</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Lielė</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Tamsus</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatiškai</translation>
    </message>
    <message>
        <source>Disable eye comfort</source>
        <translation>Išjunkite vidinės tarmybės funkciją</translation>
    </message>
    <message>
        <source>Enable eye comfort</source>
        <translation>Įjunkite vidinės tarmybės funkciją</translation>
    </message>
    <message>
        <source>Display Settings</source>
        <translation>Vidutinio nustatymai</translation>
    </message>
    <message>
        <source>Theme: Light</source>
        <translation>Apipavidalinimas: Šviesus</translation>
    </message>
    <message>
        <source>Theme: Dark</source>
        <translation>Apipavidalinimas: Tamsus</translation>
    </message>
    <message>
        <source>Theme: Auto</source>
        <translation>Apipavidalinimas: Automatinis</translation>
    </message>
    <message>
        <source>Visual effect</source>
        <translation>Žiūrovos efektas</translation>
    </message>
</context>
<context>
    <name>EyeComfortmodeApplet</name>
    <message>
        <source>Light</source>
        <translation>Viltis</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Tamsi</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatiškai</translation>
    </message>
    <message>
        <source>Theme</source>
        <translation>Apipavidalinimas</translation>
    </message>
</context>
<context>
    <name>NotificationPlugin</name>
    <message>
        <source>No messages</source>
        <translation>Nėra žinučių</translation>
    </message>
    <message>
        <source>Notification settings</source>
        <translation>Nofikacijų nustatymai</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Nofikacijos</translation>
    </message>
    <message>
        <source>Turn off DND mode</source>
        <translation>Išjungti DND režimą</translation>
    </message>
    <message>
        <source>Turn on DND mode</source>
        <translation>Perjungti DND režimą</translation>
    </message>
    <message>
        <source>Notification</source>
        <translation>Nofikacija</translation>
    </message>
</context>
<context>
    <name>OnboardPlugin</name>
    <message>
        <source>Onboard</source>
        <translation>Onboard</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Nustatymai</translation>
    </message>
</context>
<context>
    <name>PerformanceModeController</name>
    <message>
        <source>High Performance</source>
        <translation>Aukštesnio efekto</translation>
    </message>
    <message>
        <source>Balanced</source>
        <translation>Lygiavertis</translation>
    </message>
    <message>
        <source>Power Saver</source>
        <translation>Galios žiūra</translation>
    </message>
    <message>
        <source>Balance Performance</source>
        <translation>Lygiavertis efektas</translation>
    </message>
</context>
<context>
    <name>PowerApplet</name>
    <message>
        <source>Power</source>
        <translation>Galios</translation>
    </message>
</context>
<context>
    <name>PowerPlugin</name>
    <message>
        <source>Power settings</source>
        <translation>Energijos nustatymai</translation>
    </message>
    <message>
        <source>Capacity %1, %2 min remaining</source>
        <translation>Talpa %1, liko %2 min.</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr %3 min remaining</source>
        <translation>Talpa %1, liko %2 val. %3 min.</translation>
    </message>
    <message>
        <source>Charging %1, %2 min until full</source>
        <translation>Įkraunama %1, iki pilnos liko %2 min.</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr %3 min until full</source>
        <translation>Įkraunama %1, iki pilnos liko %2 val. %3 min.</translation>
    </message>
    <message>
        <source>Capacity %1</source>
        <translation>Galios dažnis %1</translation>
    </message>
    <message>
        <source>Charging %1</source>
        <translation>Įkraunama %1</translation>
    </message>
    <message>
        <source>Capacity %1 ...</source>
        <translation>Galios dažnis %1 ...</translation>
    </message>
    <message>
        <source>Capacity %1, fully charged</source>
        <translation>Galios dažnis %1, pilnai užplaukta</translation>
    </message>
    <message>
        <source>Capacity %1, not charging</source>
        <translation>Galios dažnis %1, neplauksta</translation>
    </message>
    <message>
        <source>Battery</source>
        <translation>Baterija</translation>
    </message>
    <message>
        <source>Charging, calculating estimated charging time</source>
        <translation>Plaukimas, skaičiuojama tikimybės plaukimos laiko</translation>
    </message>
    <message>
        <source>Calculating remaining usage time</source>
        <translation>Skaičiuojama likusio naudojimo laiko</translation>
    </message>
    <message>
        <source>%1 min remaining</source>
        <translation>Liko %1 min.</translation>
    </message>
    <message>
        <source>%1 hr %2 min remaining</source>
        <translation>Liko %1 val., %2 min.</translation>
    </message>
    <message>
        <source>Not charging</source>
        <translation>Ne nukšomi</translation>
    </message>
    <message>
        <source>Fully charged</source>
        <translation>Pilnai nukšomi</translation>
    </message>
    <message>
        <source>Charging, %1 min until full</source>
        <translation>Nukšomi, iki pildymo yra %1 min</translation>
    </message>
    <message>
        <source>Charging, %1 hr %2 min until full</source>
        <translation>Nukšomi, iki pildymo yra %1 val %2 min</translation>
    </message>
    <message>
        <source>Capacity %1, %2 hr remaining</source>
        <translation>Galutinės nukšymo galios %1, liko %2 val</translation>
    </message>
    <message>
        <source>%1 hr remaining</source>
        <translation>&apos;Iki pildymo liko %1 val&apos;.</translation>
    </message>
    <message>
        <source>Charging %1, %2 hr until full</source>
        <translation>Nukšomi %1, iki pildymo yra %2 val</translation>
    </message>
    <message>
        <source>Charging, %1 hr until full</source>
        <translation>Nukšomi, iki pildymo yra %1 val</translation>
    </message>
</context>
<context>
    <name>PowerStatusWidget</name>
    <message>
        <source>Power settings</source>
        <translation>Energetinių nustatymų parinktys</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Music</source>
        <translation>Muzika</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nežinoma</translation>
    </message>
</context>
<context>
    <name>ShutdownPlugin</name>
    <message>
        <source>Shut down</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pristabdyti</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Užmigdyti</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Užrakinti</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Atsijungti</translation>
    </message>
    <message>
        <source>Power settings</source>
        <translation>Energijos nustatymai</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Paleisti iš naujo</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Atnaujinti ir išjungti</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Atnaujinti ir paleisti iš naujo</translation>
    </message>
    <message>
        <source>Shut Down</source>
        <translation>Išjungti</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Pakeisti vartotoją</translation>
    </message>
</context>
<context>
    <name>SidebarCalendarWidget</name>
    <message>
        <source>Today</source>
        <translation>Šiandien</translation>
    </message>
    <message>
        <source>Lunar</source>
        <translation>Lūninos</translation>
    </message>
    <message>
        <source>y</source>
        <translation>metai</translation>
    </message>
    <message>
        <source>m</source>
        <translation>mėnesiai</translation>
    </message>
    <message>
        <source>d</source>
        <translation>dienos</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Pirmadienis</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Antradienis</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Trečiadienis</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Ketvirtadienis</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Penktadienis</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Šeštadienis</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sekmadienis</translation>
    </message>
    <message>
        <source>Jan</source>
        <translation>Sau</translation>
    </message>
    <message>
        <source>Feb</source>
        <translation>Vas</translation>
    </message>
    <message>
        <source>Mar</source>
        <translation>Kov</translation>
    </message>
    <message>
        <source>Apr</source>
        <translation>Bal</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Geg</translation>
    </message>
    <message>
        <source>Jun</source>
        <translation>Bir</translation>
    </message>
    <message>
        <source>Jul</source>
        <translation>Lie</translation>
    </message>
    <message>
        <source>Aug</source>
        <translation>Rgp</translation>
    </message>
    <message>
        <source>Sept</source>
        <translation>Rgs</translation>
    </message>
    <message>
        <source>Oct</source>
        <translation>Spa</translation>
    </message>
    <message>
        <source>Nov</source>
        <translation>Lap</translation>
    </message>
    <message>
        <source>Dec</source>
        <translation>Gru</translation>
    </message>
    <message>
        <source>Open the calendar</source>
        <translation>Atverti kalendorių</translation>
    </message>
    <message>
        <source>monday</source>
        <translation>pirmadienis</translation>
    </message>
    <message>
        <source>tuesday</source>
        <translation>antradienis</translation>
    </message>
    <message>
        <source>wednesday</source>
        <translation>trečiadienis</translation>
    </message>
    <message>
        <source>thursday</source>
        <translation>ketvirtadienis</translation>
    </message>
    <message>
        <source>friday</source>
        <translation>penktadienis</translation>
    </message>
    <message>
        <source>saturday</source>
        <translation>šeštadienis</translation>
    </message>
    <message>
        <source>sunday</source>
        <translation>sekmadienis</translation>
    </message>
</context>
<context>
    <name>SoundApplet</name>
    <message>
        <source>Volume</source>
        <translation>Garsis</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Išvestis</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Garso nustatymai</translation>
    </message>
</context>
<context>
    <name>SoundPlugin</name>
    <message>
        <source>Sound</source>
        <translation>Garsas</translation>
    </message>
</context>
<context>
    <name>SoundView</name>
    <message>
        <source>Unmute</source>
        <translation>Įjungti garsą</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>Nutildyti</translation>
    </message>
    <message>
        <source>Sound settings</source>
        <translation>Garso nustatymai</translation>
    </message>
    <message>
        <source>No output devices</source>
        <translation>Nėra išvesties įrenginių</translation>
    </message>
    <message>
        <source>Volume %1</source>
        <translation>Garsis %1</translation>
    </message>
</context>
</TS>